
;   Example script to produce plots for a WRF real-data run,
;   with the ARW coordinate dynamics option.

load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_code.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/wrf/WRFUserARW.ncl"
load "$NCARG_ROOT/lib/ncarg/nclscripts/kml/kml.ncl"

begin
;
; The WRF ARW input file.  
; This needs to have a ".nc" appended, so just do it.
;  a = addfile("/home/estatio/sandy/wrfout_d01_2012-10-30_12:00:00.nc","r")
;  b = addfile("../../sandy/wrfout_d01_2012-10-28_12:00:00.nc","r")
  fn=10
DATADir = "../../sandy/d1/"
  FILES = systemfunc (" ls -1 " + DATADir + "wrfout_d01* ")
  numFILES = dimsizes(FILES)

; We generate plots, but what kind do we prefer?
;  type = "x11"
; type = "pdf"
 type = "ps"
; type = "ncgm"


; Set some basic resources
  res = True
;  res@MainTitle                   = "REAL-TIME WRF"

  pltres = True
  mpres = True

  pltres@FramePlot = False
  pltres@DrawPlot = False
  mpres = True
  mpres0 = True
  pltres@NoTitles=True
  mpres0@gsnMaximize   = True
 mpres0@mpOutlineOn= False

;************************************************
;  position resources for ScreenOverlay element
;************************************************

  kres = True
  kml = kml_open_document("sandy", "SANDY PATH",False)
  kml_folder = kml_open_folder(kml, "GroundOverlay Folder",False)   ; put all GroundOverlay elements in one folder

;************************************************
;  position resources for ScreenOverlay element
;************************************************

  kres@kmlOverlayXY  = True
  kres@kmlOverlayXYx  = 0
  kres@kmlOverlayXYy  = 0
  kres@kmlOverlayXYxunits = "fraction" ;
  kres@kmlOverlayXYyunits = "fraction" ; pixels, or insetPixels
  kres@kmlScreenXY = True
  kres@kmlScreenXYx = 0
  kres@kmlScreenXYy = 0
  kres@kmlScreenXYxunits = "fraction"
  kres@kmlScreenXYyunits = "fraction"

;************************************************
; add the label bar as a ScreenOverlay
;************************************************
; lbicon = kml_crop_labelbar(kml, "label bar", wks,plot, kres)      ; crops the labelbar from the plot and converts it to a png
;  kml = kml_add_screenoverlay ( kml, "Label Bar", lbicon, kres)     ; add labelbar to KML document as a ScreenOverlay element
;  kml_add_kmzfile(kml,lbicon)                                       ; add cropped labelbar filename to list of files to be compressed in KMZ archive
 lbicon="bard1.gif"
 kml = kml_add_screenoverlay ( kml, "Label Bar", lbicon, kres)     ; add labelbar to KML document as a ScreenOverlay element
 kml_add_kmzfile(kml,lbicon)                                       ; add cropped labelbar filename to list of files to be compressed in KMZ archive
  kres@kmlHeading = -6                                             ; define a heading for the LookAt element
kml = kml_add_lookat( kml, -73, 36, 0.0, 4000000, kres)           ; add a LookAt element

;numFILES=17
do ifil = 0,numFILES-1

 wks = gsn_open_wks(type,ifil)


 a = addfile(FILES(ifil)+".nc","r")
if(ifil.lt.numFILES-1)
 b = addfile(FILES(ifil+1)+".nc","r") ;dummy variable for endtime
end if
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

; What times and how many time steps are in the data set?
  times  = wrf_user_list_times(a)  ; get times in the file
  ntimes = dimsizes(times)         ; number of times in the file
  timesend  = wrf_user_list_times(b)  ; get times in the file


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;  do it = 0,ntimes-1,2             ; TIME LOOP
it=0
;    print("Working on time: " + times(it) )
    res@TimeLabel = times(it)   ; Set Valid time to use on plots




; We are interested in a zoomed area with the SW corner at 20N;90W,
; and the NE corner at 30N;80W
; So get the XY points of these points
;lats = (/  40.68,  40.87 /) ;Manhattan
lats = (/  23.4381,  45.7626 /)
lons = (/ -82.9741, -62.2103 /)
;lons = (/ -74.15, -73.79 /)  ;Manhattan
loc = wrf_user_ll_to_ij(b, lons, lats, True)

; loc(0,;) is west-east (x) ; loc(1,:) is south-north (y)
; subtract one since we want to use it as an index in NCL
  x_start = loc(0,0) - 1
  x_end   = loc(0,1) - 1
  y_start = loc(1,0) - 1
  y_end   = loc(1,1) - 1

  mpres0@ZoomIn = True        ; set up map info for zoomed area
  mpres0@Xstart = x_start
  mpres0@Ystart = y_start
  mpres0@Xend = x_end
  mpres0@Yend = y_end




;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; First get the variables we will need        

    slp = wrf_user_getvar(a,"slp",it)    ; slp
      wrf_smooth_2d( slp, 3 )            ; smooth slp
    tc = wrf_user_getvar(a,"tc",it)      ; 3D tc 
    td = wrf_user_getvar(a,"td",it)      ; 3D td 
    u  = wrf_user_getvar(a,"ua",it)      ; 3D U at mass points
    v  = wrf_user_getvar(a,"va",it)      ; 3D V at mass points
    td2 =  wrf_user_getvar(a,"td2",it)   ; Td2 in C
    tc2 = wrf_user_getvar(a,"T2",it)     ; T2 in Kelvin
       tc2 = tc2-273.16                  ; T2 in C
    u10 = wrf_user_getvar(a,"U10",it)    ; u at 10 m, mass point
    v10 = wrf_user_getvar(a,"V10",it)    ; v at 10 m, mass point

    tf2 = 1.8*tc2+32.                    ; Turn temperature into Fahrenheit
      tf2@description = "Surface Temperature"
      tf2@units = "F"
    td_f = 1.8*td2+32.                   ; Turn temperature into Fahrenheit
      td_f@description = "Surface Dew Point Temp" 
      td_f@units = "F"
spd = ((u10*u10 + v10*v10)^(0.5))*2.24
;spd@description = "Wind Speed"
;spd@units="mph"
    u10 = u10*1.94386                    ; Turn wind into knots
    v10 = v10*1.94386
      u10@units = "kts"
      v10@units = "kts"
;    r1  = wrf_user_getvar(b,"RAINNC",0)   ; theta
    r2  = wrf_user_getvar(a,"RAINNC",0)   ; theta
;    rc  = r2-r1
;u10z=u10(y_start:y_end,x_start:x_end)
;v10z=v10(y_start:y_end,x_start:x_end)
;slpz=slp(y_start:y_end,x_start:x_end) 
;spdz=spd(y_start:y_end,x_start:x_end)


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

  mpres = True
  mpres = True
  pltres@NoTitles=True
  mpres@gsnMaximize   = True
  mpres@mpOutlineOn= False
  mpres@mpOutlineBoundarySets = "national"
  mpres@mpOceanFillColor=0
  mpres@mpGeophysicalLineColor      = "black"   ; Overwrite map settings
  mpres@mpGridLineColor             = "Black"
  mpres@mpLimbLineColor             = "Black"
  mpres@mpNationalLineColor         = "black"
  mpres@mpPerimLineColor            = "Black"
  mpres@mpUSStateLineColor          = "Black"
  mpres@mpGeophysicalLineThicknessF = 1.4
    mpres@mpNationalLineThicknessF    = 1.4


    

; Plotting options for T               
      gsn_define_colormap(wks,"nrl_sirkes") 
      opts = res                         
      opts@cnFillOn = True  
      opts@ContourParameters = (/ 20., 90., 10./)
      opts@gsnSpreadColorStart = 6
     ; opts@gsnSpreadColorEnd = -3  ; End third from the last color in color map
      ;opts@mpNationalLineColor=0
      contour_tc = wrf_contour(a,wks,spd,opts)
      delete(opts)



    ; Plotting options for SLP                     
      opts = res         
      opts@cnLineColor = "Red"
      opts@cnHighLabelsOn = True
      opts@cnLowLabelsOn = True
      opts@ContourParameters = (/ 900., 1100., 4. /)
      opts@cnLineLabelBackgroundColor = -1
      opts@gsnContourLineThicknessesScale = 3.0
      contour_psl = wrf_contour(a,wks,slp,opts)
      delete(opts)

    ; Plotting options for Wind Vectors                 
      opts = res         
      opts@FieldTitle = "Wind"       ; overwrite Field Title
      opts@NumVectors = 47           ; density of wind barbs
      vector = wrf_vector(a,wks,u10,v10,opts)
      delete(opts)
  

    ; MAKE PLOTS                                       
      plot = wrf_map_overlays(a,wks,(/contour_tc,contour_psl,vector/),pltres,mpres)

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;



;************************************************
;  add the map as a GroundOverlay
;************************************************

  LatLonBox = kml_get_vp_latlonbox(plot)    ; get the latlon coordinates describing the corners of the groundoverlay plot
  LatLonBox = (/ lats(1), lats(0), lons(1), lons(0) /)
 print(LatLonBox)
 cropbox = kml_get_vp_cropbox(wks,plot)    ; get the page coordinates of the actual map from the plot
 cropbox(3)=79
 cropbox(1)=437
print(cropbox)
  delete(wks)                               ; must delete wks before cropping map



;************************************************
;   dating format to kml
;************************************************

times(0)=str_sub_str(times(0),"_","T")
times(0)=str_sub_str(times(0),":00:00",":00Z")
timesend(0)=str_sub_str(timesend(0),"_","T")
timesend(0)=str_sub_str(timesend(0),":00:00",":00Z")


stimebegin=times(0)
stimeend=timesend(0)


 kres@kmlTimeSpanBegin = stimebegin         ; set a begin time for the timespan element
 kres@kmlTimeSpanEnd   = stimeend           ; set an end time for the timespan element




;  kres@kmlCropAlphaColor = "white"          ; kml_crop_plot will now set white areas of the map to transparent
  icon = kml_crop_plot(cropbox, kres)       ; crops the groundoverlay map and converts it to png

  kres@kmlColor = "99ffffff"                                                     ; set alpha channel for overlay to make it appear partially transparent in Google Earth
  kml = kml_add_groundoverlay(kml, "GroundOverlay", icon, LatLonBox, 0, kres)    ; add cropped map to KML document as a GroundOverlay element
  kml_add_kmzfile(kml,icon)                                                      ; add cropped map filename to list of files to be compressed in KMZ archive
  delete(kres@kmlColor)





draw(plot)
;frame(wks)




; delete(wks)

;  cmd = "convert -geometry 600x1000 -density 1200 -trim " + "0" + ".ps " + \
 ;                                                        fn + ".gif"
 ; system(cmd)





  end do        ; END OF TIME LOOP

;************************************************
;  close, write, and archive the KML document
;************************************************
  kml_folder=kml_close_folder(kml) ; close the folder
  kml = kml_close_document(kml)    ; close the kml document
  kml_write(kml)                   ; write kml document to file "example06.kmz"
  kml_make_kmz(kml)                ; zip kml file and overlay images together in to "example06.kmz"





end
